@@ -9,12 +9,15 @@ from djangoldp_conversation.models import Conversation, Message
 from djangoldp_like.models import Like
 from django.utils import timezone
 from django.template import loader
+from djangoldp_i18n.views import I18nLDPViewSet
 
 class LearningOutcome (Model) :
     name = models.CharField(max_length=256, verbose_name="Learning outcome")
     
     class Meta:
         rdf_type = 'coopstarter:skills'
+        view_set = I18nLDPViewSet
+        depth = 0
 
     def __str__(self):
         return self.name
@@ -69,6 +72,8 @@ class Step (Model):
         nested_fields=["resources"]
         container_path = 'steps/'
         rdf_type = 'coopstarter:step'
+        view_set = I18nLDPViewSet
+        depth = 0
     
     def __str__(self):
         return self.name
@@ -78,6 +83,8 @@ class Format (Model):
 
     class Meta:
         rdf_type = 'coopstarter:format'
+        view_set = I18nLDPViewSet
+        depth = 0
 
     def __str__(self):
         return self.name
@@ -87,6 +94,8 @@ class Field (Model):
 
     class Meta:
         rdf_type = 'coopstarter:field'
+        view_set = I18nLDPViewSet
+        depth = 0
 
     def __str__(self):
         return self.name
@@ -96,6 +105,8 @@ class Type (Model):
 
     class Meta:
         rdf_type = 'coopstarter:resourcetype'
+        view_set = I18nLDPViewSet
+        depth = 0
 
     def __str__(self):
         return self.name
@@ -106,6 +117,8 @@ class Target (Model):
 
     class Meta:
         rdf_type = 'coopstarter:target'
+        view_set = I18nLDPViewSet
+        depth = 0
 
     def __str__(self):
         return self.name
@@ -116,6 +129,8 @@ class SharingCriteria (Model):
 
     class Meta:
         rdf_type = 'coopstarter:sharingcriteria'
+        view_set = I18nLDPViewSet
+        depth = 0
 
     def __str__(self):
         return self.name
@@ -230,15 +245,20 @@ class Resource (Model):
         auto_author='submitter'
         owner_field = 'submitter'
         owner_perms = ['inherit', 'change', 'control', 'delete']
-        nested_fields=["format", "conversations", "steps", "languages", "fields",\
-                       "type", "submitter", "related", "likes", "review", "country", "skills"]
-        serializer_fields=["@id", "name", "description", "skills", "resource_author", "target", "uri", "publication_year", "format",\
+        nested_fields=["submitter",\
+                       "format", "conversations", "steps", "languages", "fields",\
+                       "type", "related", "likes", "review", "country", "skills"]
+        serializer_fields=["@id", "name", "description", "resource_author", "uri", "publication_year", "submitter",\
+                           "format", "target", "skills",\
                            "conversations", "steps", "languages", "fields", "country",\
-                           "type", "submitter", "related", "likes", "review", "sharing", "preview_image", "iframe_link"]
+                           "type", "submitter", "related", "likes", "review", "sharing",\
+                           "preview_image", "iframe_link"]
         container_path = 'resources/'
         rdf_type = 'coopstarter:resource'
         anonymous_perms = ['view']
         authenticated_perms = ['inherit', 'add']
+        view_set = I18nLDPViewSet
+        depth = 0
 
     def __str__(self):
         return self.name
