@@ -1,8 +1,8 @@
 from djangoldp.views import LDPViewSet
 from .models import Resource, Step
+from djangoldp_i18n.views import I18nLDPViewSet
 
-
-class ValidatedResourcesByStepViewSet(LDPViewSet):
+class ValidatedResourcesByStepViewSet(I18nLDPViewSet):
   model = Resource
 
   def get_queryset(self, *args, **kwargs):
@@ -19,7 +19,7 @@ class ValidatedResourcesByStepViewSet(LDPViewSet):
           .filter(steps__in=step_id, review__status='validated')\
           .exclude(submitter__username=self.request.user.username)
 
-class PendingResourcesViewSet(LDPViewSet):
+class PendingResourcesViewSet(I18nLDPViewSet):
   model = Resource
 
   def get_queryset(self, *args, **kwargs):
